/*****************************************************************************/
/* This is a basic example illustrating the use of the HepMC Visual library  */
/* in a standalone application.                                              */
/*                                                                           */
/* To run this example:                                                      */
/*  - Make sure ROOT version >= 5.10 is installed                            */
/*  - Make sure HepMC and HepMCVisual libraries are compiled and installed   */
/*    NOTE: if you didn't install in the default directory, you may need to  */
/*    modify the Makefile                                                    */
/*  - Make sure the directories holding the HepMC and HepMCVisual libraries  */
/*    are in your LD_LIBRARY_PATH                                            */
/*  - From the command line run the following commands:                      */
/*    > gmake basic                                                          */
/*    > ./basic                                                              */
/*                                                                           */
/* In case of problems, please write an email to:                            */
/*    hepmcvisual at projects.hepforge.org                                   */
/*                                                                           */
/*                                           Enjoy, Sebastian                */
/*****************************************************************************/

#include <TROOT.h>
#include <TApplication.h>
#include <TCanvas.h>
#include <TSystem.h>
#include <Riostream.h>
#include <stdlib.h>
#include <stdio.h>
#include <TArrow.h>

#include "HepMCVisual/HepMCVisualElements.h"
#include "HepMC/IO_PDG_ParticleDataTable.h"

using namespace HepMC;

int main( int argc, char** argv ){

   /**
    * Create a basic root application
    */
   TApplication theApp("App", &argc, argv);
 
   if (gROOT->IsBatch()) {
      fprintf(stderr, "%s: cannot run in batch mode\n", argv[0]);
      return 1;
   }
 
   // Create a canvas to display the event
   TCanvas* chepmc = new TCanvas("chepmc","HepMCVisual Demo",600,600);

   /**
    * Construct a primitive HepMC event - this step can be left out if you have
    * another source of HepMC event records
    */
   VisualVertex * v0 = new VisualVertex(0.35,0.5);
   VisualVertex * v1 = new VisualVertex(0.65,0.5);

   // Z->e+e- with 90deg opening angle in lab-frame
   double m_e = 0.511;
   double m_Z = 91.187e3;
   double p_e = 0.5*sqrt(m_Z*m_Z - 4*m_e*m_e);
   double E_e = sqrt(0.5*m_Z*m_Z-m_e*m_e);
   VisualParticle * p1 = new VisualParticle(FourVector(0,0,p_e,E_e),11);

   v0->add_particle_out(p1);
   v1->add_particle_in(p1);
   p1->SetShow(kTRUE);

   VisualEvent* VisEvt = new VisualEvent(1,0,0);
   VisEvt->add_vertex(v0);
   VisEvt->add_vertex(v1);

   /**
    * Load a PDG table - this is necessary to display particle properties
    */
   IO_PDG_ParticleDataTable iopdt("PDG_table_2008.mc");
   ParticleDataTable* pdt = iopdt.read_particle_data_table();
   pdt->make_antiparticles_from_particles();

   /**
    * Finally visualize the event
    */
   //VisualEvent* VisEvt = Visualize(evt);
   VisEvt->SetPDT(pdt);
   VisEvt->Draw();

   //Run the application (i.e. make the canvas react on user events)
   theApp.Run();
 
   return 0;
}
